@@ -1,4 +1,4 @@
-## ---- include = FALSE---------------------------------------------------------
+## ----include = FALSE----------------------------------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#>",
@@ -9,14 +9,14 @@ knitr::opts_chunk$set(
 library(ftExtra)
 
 ## -----------------------------------------------------------------------------
-ft <- iris[1:2, ] %>% as_flextable
+ft <- iris[1:2, ] %>% flextable
 ft
 
 ## -----------------------------------------------------------------------------
-ft %>% separate_header()
+ft %>% split_header()
 
 ## -----------------------------------------------------------------------------
-ft %>% separate_header(sep = "e")
+ft %>% split_header(sep = "e")
 
 ## -----------------------------------------------------------------------------
 ft %>% span_header()
